@@ -5,6 +5,7 @@ class OAGQueryRequestObject:
         self.arrival_airport = ""
         self.departure_date = ""
         self.departure_hour = ""
+        self.arrival_date = ""
         self.arrival_hour = ""
         self.airline = ""
 
@@ -14,8 +15,9 @@ class OAGQueryRequestObject:
         arrival_airport = "" if self.arrival_airport == "" else "ARRAP={}&".format(self.arrival_airport)
         departure_date = "" if self.departure_date == "" else "DEPDATE={}&".format(self.departure_date)
         departure_hour = "" if self.departure_hour == "" else "DEPHR={}&".format(self.departure_hour)
+        arrival_date = "" if self.arrival_date == "" else "ARRDATE={}&".format(self.arrival_date)
         arrival_hour = "" if self.arrival_hour == "" else "ARRHR={}&".format(self.arrival_hour)
         airline = "" if self.airline == "" else "AL={}&".format(self.airline)
 
-        return "{}{}{}{}{}{}{}".format(aircraft_id, departure_airport, arrival_airport, departure_date,
-                                             departure_hour, arrival_hour, airline)
\ No newline at end of file
+        return "{}{}{}{}{}{}{}{}".format(aircraft_id, departure_airport, arrival_airport, departure_date,
+                                             departure_hour, arrival_date, arrival_hour, airline)
\ No newline at end of file
